@@ -1,6 +1,9 @@
+# frozen_string_literal: true
+
 module JekyllData
   class ThemeDataReader < Jekyll::DataReader
     attr_reader :site, :content
+
     def initialize(site)
       @site = site
       @content = {}
@@ -9,6 +12,7 @@ module JekyllData
 
     def read(dir)
       return unless site.theme && site.theme.data_path
+
       base = site.in_theme_dir(dir)
       read_data_to(base, @content)
       @content
@@ -18,7 +22,7 @@ module JekyllData
       return unless File.directory?(dir) && !@entry_filter.symlink?(dir)
 
       entries = Dir.chdir(dir) do
-        Dir["*.{yaml,yml,json,csv}"] + Dir["*"].select { |fn| File.directory?(fn) }
+        Dir["*.{yaml,yml,json,csv,tsv}"] + Dir["*"].select { |fn| File.directory?(fn) }
       end
 
       entries.each do |entry|
