@@ -1,4 +1,4 @@
-# encoding: UTF-8
+# frozen_string_literal: true
 
 module JekyllData
   class ThemedSiteDrop < Jekyll::Drops::SiteDrop
@@ -9,7 +9,6 @@ module JekyllData
     def_delegator  :@obj, :site_data, :data
     def_delegators :@obj, :theme
 
-    private
-    def_delegator :@obj, :config, :fallback_data
+    private def_delegator :@obj, :config, :fallback_data
   end
 end
