@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 module Jekyll
   class Theme
     def data_path
-      path_for "_data".freeze
+      @data_path ||= path_for "_data"
     end
   end
 end
